@@ -1,21 +1,33 @@
 use bevy::prelude::*;
+use bevy_ascii_terminal::*;
+use bevy_tiled_camera::*;
 
-use bevy_ascii_terminal::{terminal::Terminal, TerminalBundle, TerminalPlugin};
-use bevy_pixel_camera::{PixelCameraBundle, PixelCameraPlugin};
+fn main() {
+    App::build()
+        .add_plugins(DefaultPlugins)
+        .add_plugin(TerminalPlugin)
+        .add_plugin(TiledCameraPlugin)
+        .insert_resource(ClearColor(Color::BLACK))
+        .add_startup_system(spawn_terminal.system())
+        .add_system(hello_world.system())
+        .run()
+}
 
 fn spawn_terminal(mut commands: Commands) {
-    let (w, h) = (20, 3);
-    let mut term_bundle = TerminalBundle::with_size(w, h);
+    let size = (20, 3);
+    let mut term_bundle = TerminalBundle::new().with_size(size);
 
     term_bundle.terminal.draw_border_single();
-    term_bundle.terminal.put_string(1, 1, "Press spacebar");
+    term_bundle.terminal.put_string((1, 1), "Press spacebar");
 
     commands.spawn_bundle(term_bundle);
 
-    commands.spawn_bundle(PixelCameraBundle::from_resolution(
-        w as i32 * 8,
-        h as i32 * 8,
-    ));
+    commands.spawn_bundle(
+        TiledCameraBundle::new()
+            .with_centered(true)
+            .with_pixels_per_tile(8)
+            .with_tile_count(size),
+    );
 }
 
 fn hello_world(keys: Res<Input<KeyCode>>, mut q: Query<&mut Terminal>) {
@@ -23,18 +35,7 @@ fn hello_world(keys: Res<Input<KeyCode>>, mut q: Query<&mut Terminal>) {
         for mut term in q.iter_mut() {
             term.clear();
             term.draw_border_single();
-            term.put_string(1, 1, "Hello, world!");
+            term.put_string((1, 1), "Hello, world!");
         }
     }
 }
-
-fn main() {
-    App::build()
-        .add_plugins(DefaultPlugins)
-        .add_plugin(TerminalPlugin)
-        .insert_resource(ClearColor(Color::BLACK))
-        .add_plugin(PixelCameraPlugin)
-        .add_startup_system(spawn_terminal.system())
-        .add_system(hello_world.system())
-        .run()
-}
